@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2008-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2008-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2010 by Yoann Laissus <yoann dot laissus at gmail dot com>
 *
 *
@@ -34,7 +34,7 @@
 #include "bookmarkscontextmenu.h"
 #include "mainwindow.h"
 #include "application.h"
-#include "bookmarkprovider.h"
+#include "bookmarkmanager.h"
 #include "bookmarkowner.h"
 #include "webtab.h"
 
@@ -136,7 +136,7 @@ void BookmarkMenu::addOpenFolderInTabs()
 
         if (!bookmark.isNull())
         {
-            parentMenu()->addAction(rApp->bookmarkProvider()->bookmarkOwner()->createAction(group, BookmarkOwner::OPEN_FOLDER));
+            parentMenu()->addAction(rApp->bookmarkManager()->owner()->createAction(group, BookmarkOwner::OPEN_FOLDER));
         }
     }
 }
@@ -163,15 +163,15 @@ BookmarkToolBar::BookmarkToolBar(KToolBar *toolBar, QObject *parent)
     , m_filled(false)
 {
     toolBar->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(toolBar, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(contextMenu(const QPoint &)));
-    connect(rApp->bookmarkProvider()->bookmarkManager(), SIGNAL(changed(QString, QString)), this, SLOT(hideMenu()));
+    connect(toolBar, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(contextMenu(QPoint)));
+    connect(rApp->bookmarkManager()->manager(), SIGNAL(changed(QString,QString)), this, SLOT(hideMenu()));
     toolBar->setAcceptDrops(true);
     toolBar->installEventFilter(this);
     toolBar->setShortcutEnabled(false);
 
     if (toolBar->isVisible())
     {
-        rApp->bookmarkProvider()->fillBookmarkBar(this);
+        rApp->bookmarkManager()->fillBookmarkBar(this);
         m_filled = true;
     }
 }
@@ -186,7 +186,7 @@ KToolBar* BookmarkToolBar::toolBar()
 void BookmarkToolBar::contextMenu(const QPoint &point)
 {
     KBookmarkActionInterface *action = dynamic_cast<KBookmarkActionInterface*>(toolBar()->actionAt(point));
-    KBookmark bookmark = rApp->bookmarkProvider()->bookmarkManager()->toolbar();
+    KBookmark bookmark = rApp->bookmarkManager()->manager()->toolbar();
     bool nullAction = true;
     if (action)
     {
@@ -195,8 +195,8 @@ void BookmarkToolBar::contextMenu(const QPoint &point)
     }
 
     BookmarksContextMenu menu(bookmark,
-                              rApp->bookmarkProvider()->bookmarkManager(),
-                              rApp->bookmarkProvider()->bookmarkOwner(),
+                              rApp->bookmarkManager()->manager(),
+                              rApp->bookmarkManager()->owner(),
                               nullAction);
     menu.exec(toolBar()->mapToGlobal(point));
 }
@@ -252,7 +252,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     {
         if (!m_filled)
         {
-            rApp->bookmarkProvider()->fillBookmarkBar(this);
+            rApp->bookmarkManager()->fillBookmarkBar(this);
             m_filled = true;
         }
     }
@@ -289,7 +289,9 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     case QEvent::DragEnter:
     {
         QDragEnterEvent *dragEvent = static_cast<QDragEnterEvent*>(event);
-        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark") || dragEvent->mimeData()->hasFormat("text/uri-list") || dragEvent->mimeData()->hasFormat("text/plain"))
+        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark")
+            || dragEvent->mimeData()->hasFormat("text/uri-list")
+            || dragEvent->mimeData()->hasFormat("text/plain"))
         {
             QFrame* dropIndicatorWidget = new QFrame(toolBar());
             dropIndicatorWidget->setFrameShape(QFrame::VLine);
@@ -319,7 +321,9 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     case QEvent::DragMove:
     {
         QDragMoveEvent *dragEvent = static_cast<QDragMoveEvent*>(event);
-        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark") || dragEvent->mimeData()->hasFormat("text/uri-list") || dragEvent->mimeData()->hasFormat("text/plain"))
+        if (dragEvent->mimeData()->hasFormat("application/rekonq-bookmark")
+            || dragEvent->mimeData()->hasFormat("text/uri-list")
+            || dragEvent->mimeData()->hasFormat("text/plain"))
         {
             QAction *overAction = toolBar()->actionAt(dragEvent->pos());
             KBookmarkActionInterface *overActionBK = dynamic_cast<KBookmarkActionInterface*>(overAction);
@@ -388,7 +392,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     {
         QDropEvent *dropEvent = static_cast<QDropEvent*>(event);
         KBookmark bookmark;
-        KBookmarkGroup root = rApp->bookmarkProvider()->bookmarkManager()->toolbar();
+        KBookmarkGroup root = rApp->bookmarkManager()->manager()->toolbar();
 
         if (m_checkedAction)
         {
@@ -399,7 +403,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
         if (dropEvent->mimeData()->hasFormat("application/rekonq-bookmark"))
         {
             QByteArray addresses = dropEvent->mimeData()->data("application/rekonq-bookmark");
-            bookmark =  rApp->bookmarkProvider()->bookmarkManager()->findByAddress(QString::fromLatin1(addresses.data()));
+            bookmark =  rApp->bookmarkManager()->findByAddress(QString::fromLatin1(addresses.data()));
             if (bookmark.isNull())
                 return false;
         }
@@ -481,7 +485,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
                 }
 
 
-                rApp->bookmarkProvider()->bookmarkManager()->emitChanged();
+                rApp->bookmarkManager()->emitChanged();
             }
         }
         else
@@ -493,7 +497,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
                 root.moveBookmark(bookmark, KBookmark());
             }
 
-            rApp->bookmarkProvider()->bookmarkManager()->emitChanged();
+            rApp->bookmarkManager()->emitChanged();
         }
         dropEvent->accept();
     }
@@ -506,7 +510,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
     QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
 
     // These events need to be handled only for Bookmark actions and not the bar
-    if (watched != toolBar() && mouseEvent && mouseEvent->button() != Qt::MidButton)
+    if (watched != toolBar() && mouseEvent)
     {
         switch (event->type())
         {
@@ -515,7 +519,7 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
             QPoint pos = toolBar()->mapFromGlobal(QCursor::pos());
             KBookmarkActionInterface *action = dynamic_cast<KBookmarkActionInterface *>(toolBar()->actionAt(pos));
 
-            if (action)
+            if (action && mouseEvent->button() != Qt::MidButton)
             {
                 m_dragAction = toolBar()->actionAt(pos);
                 m_startDragPos = pos;
@@ -539,14 +543,22 @@ bool BookmarkToolBar::eventFilter(QObject *watched, QEvent *event)
 
         case QEvent::MouseButtonRelease:
         {
-            int distance = (toolBar()->mapFromGlobal(QCursor::pos()) - m_startDragPos).manhattanLength();
-            KBookmarkActionInterface *action = dynamic_cast<KBookmarkActionInterface *>(toolBar()->actionAt(m_startDragPos));
+            QPoint destPos = toolBar()->mapFromGlobal(QCursor::pos());
+            int distance = (destPos - m_startDragPos).manhattanLength();
+            KBookmarkActionInterface *action = dynamic_cast<KBookmarkActionInterface *>(toolBar()->actionAt(destPos));
 
-            if (action && action->bookmark().isGroup() && distance < QApplication::startDragDistance())
+            if (action && action->bookmark().isGroup())
             {
-                KBookmarkActionMenu *menu = dynamic_cast<KBookmarkActionMenu *>(toolBar()->actionAt(m_startDragPos));
-                QPoint actionPos = toolBar()->mapToGlobal(toolBar()->widgetForAction(menu)->pos());
-                menu->menu()->popup(QPoint(actionPos.x(), actionPos.y() + toolBar()->widgetForAction(menu)->height()));
+                if (mouseEvent->button() == Qt::MidButton)
+                {
+                    rApp->bookmarkManager()->owner()->openBookmarkFolder(action->bookmark());
+                }
+                else if (distance < QApplication::startDragDistance())
+                {
+                    KBookmarkActionMenu *menu = dynamic_cast<KBookmarkActionMenu *>(toolBar()->actionAt(m_startDragPos));
+                    QPoint actionPos = toolBar()->mapToGlobal(toolBar()->widgetForAction(menu)->pos());
+                    menu->menu()->popup(QPoint(actionPos.x(), actionPos.y() + toolBar()->widgetForAction(menu)->height()));
+                }
             }
         }
         break;
