@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2010-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2010-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -31,12 +31,12 @@
 // Local Includes
 #include "application.h"
 #include "webicon.h"
+#include "icondownloader.h"
 
 // KDE Includes
 #include <KIO/Job>
 
 #include <KIcon>
-#include <KMimeType>
 #include <KStandardDirs>
 #include <KUrl>
 
@@ -75,6 +75,8 @@ KIcon IconManager::iconForUrl(const KUrl &url)
         return KIcon("emblem-favorite");
     if (encodedUrl == QByteArray("about:downloads"))
         return KIcon("download");
+    if (encodedUrl == QByteArray("about:tabs"))
+        return KIcon("tab-duplicate");
 
     // TODO: return other mimetype icons
     if (url.isLocalFile())
@@ -82,11 +84,10 @@ KIcon IconManager::iconForUrl(const KUrl &url)
         return KIcon("folder");
     }
 
-    QString i = KMimeType::favIconForUrl(url);
+    QString i = favIconForUrl(url);
     if (!i.isEmpty())
     {
-        QString faviconDir = KStandardDirs::locateLocal("cache" , "" , true);
-        return KIcon(faviconDir + i);
+        return KIcon(QIcon(_faviconsDir + i));
     }
 
     // Not found icon. Return default one.
@@ -94,7 +95,7 @@ KIcon IconManager::iconForUrl(const KUrl &url)
 }
 
 
-void IconManager::provideIcon(QWebPage *page, const KUrl &url, bool notify)
+void IconManager::provideIcon(QWebFrame *mFrame, const KUrl &url, bool notify)
 {
     // provide icons just for http/https sites
     if (!url.scheme().startsWith(QL1S("http")))
@@ -113,7 +114,7 @@ void IconManager::provideIcon(QWebPage *page, const KUrl &url, bool notify)
     }
 
     // check if icon exists
-    if (!KMimeType::favIconForUrl(url).isEmpty())
+    if (!favIconForUrl(url).isEmpty())
     {
         if (notify)
             emit iconChanged();
@@ -126,7 +127,8 @@ void IconManager::provideIcon(QWebPage *page, const KUrl &url, bool notify)
     // find favicon url
     KUrl faviconUrl(rootUrlString + QL1S("/favicon.ico"));
 
-    QWebElement root = page->mainFrame()->documentElement();
+
+    QWebElement root = mFrame->documentElement();
     QWebElement e = root.findFirst(QL1S("link[rel~=\"icon\"]"));
     QString relUrlString = e.attribute(QL1S("href"));
     if (relUrlString.isEmpty())
@@ -139,18 +141,15 @@ void IconManager::provideIcon(QWebPage *page, const KUrl &url, bool notify)
     {
         faviconUrl = relUrlString.startsWith(QL1S("http"))
                      ? KUrl(relUrlString)
-                     : KUrl(rootUrlString + QL1C('/') + relUrlString) ;
+                     : KUrl(rootUrlString + QL1C('/') + relUrlString);
     }
 
     // dest url
-    KUrl destUrl(_faviconsDir + url.host() + QL1S(".png"));
+    KUrl destUrl(_faviconsDir + url.host());
 
-    // download icon
-    KIO::FileCopyJob *job = KIO::file_copy(faviconUrl, destUrl, -1, KIO::HideProgressInfo);
+    IconDownloader *id = new IconDownloader(faviconUrl, destUrl, this);
     if (notify)
-        connect(job, SIGNAL(result(KJob*)), this, SLOT(notifyLastStuffs(KJob *)));
-    else
-        connect(job, SIGNAL(result(KJob*)), this, SLOT(doLastStuffs(KJob *)));
+        connect(id, SIGNAL(iconReady()), this, SIGNAL(iconChanged()));
 }
 
 
@@ -171,57 +170,95 @@ void IconManager::clearIconCache()
 }
 
 
-void IconManager::doLastStuffs(KJob *j)
+void IconManager::saveDesktopIconForUrl(const KUrl &u)
 {
-    if (j->error())
-    {
-        kDebug() << "FAVICON JOB ERROR";
-        return;
-    }
+    KIcon icon = iconForUrl(u);
+    QString destPath = _faviconsDir + u.host() + QL1S("_WEBAPPICON.png");
 
-    KIO::FileCopyJob *job = static_cast<KIO::FileCopyJob *>(j);
-    KUrl dest = job->destUrl();
+    QPixmap pix = icon.pixmap(16, 16);
+    int s = KIconLoader::global()->currentSize(KIconLoader::Desktop);
+    pix = pix.scaled(s, s);
 
-    QString s = dest.url().remove(QL1S("file://"));
-    QFile fav(s);
-    if (!fav.exists())
-    {
-        kDebug() << "FAVICON DOES NOT EXISTS";
-        fav.remove();
-        return;
-    }
-
-    if (fav.size() == 0)
-    {
-        kDebug() << "SIZE ZERO FAVICON";
-        fav.remove();
-        return;
-    }
-
-    QPixmap px;
-    if (!px.load(s))
-    {
-        kDebug() << "PIXMAP NOT LOADED";
-        return;
-    }
-
-    if (px.isNull())
-    {
-        kDebug() << "PIXMAP IS NULL";
-        fav.remove();
-        return;
-    }
-
-    px = px.scaled(16, 16);
-    if (!px.save(s))
-    {
-        kDebug() << "PIXMAP NOT SAVED";
-        return;
-    }
+    pix.save(destPath);
 }
 
-void IconManager::notifyLastStuffs(KJob *j)
+
+// NOTE: this function is builded "around" the iconForurl one. It basically returns the same things
+// with an important difference: this one returns paths while the other one returns KIcons
+QString IconManager::iconPathForUrl(const KUrl &url)
 {
-    doLastStuffs(j);
-    emit iconChanged();
+    // first things first.. avoid infinite loop at startup
+    if (url.isEmpty() || rApp->mainWindowList().isEmpty())
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/mimetypes/text-html.png");
+        return icon;
+    }
+
+    QByteArray encodedUrl = url.toEncoded();
+    // rekonq icons..
+    if (encodedUrl == QByteArray("about:home"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/actions/go-home.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:closedTabs"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/actions/tab-close.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:history"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/actions/view-history.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:bookmarks"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/places/bookmarks.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:favorites"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/emblems/emblem-favorite.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:downloads"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/actions/download.png");
+        return icon;
+    }
+    if (encodedUrl == QByteArray("about:tabs"))
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/actions/tab-duplicate.png");
+        return icon;
+    }
+
+    // TODO: return other mimetype icons
+    if (url.isLocalFile())
+    {
+        QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/places/folder.png");
+        return icon;
+    }
+
+    QString i = favIconForUrl(url);
+    if (!i.isEmpty())
+    {
+        return QL1S("file://") + _faviconsDir + i;
+    }
+
+    // Not found icon. Return default one.
+    QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/mimetypes/text-html.png");
+    return icon;
+}
+
+
+QString IconManager::favIconForUrl(const KUrl &url)
+{
+    if (url.isLocalFile()
+            || !url.protocol().startsWith(QL1S("http")))
+        return QString();
+
+    if (QFile::exists(_faviconsDir + url.host() + QL1S(".png")))
+        return url.host() + QL1S(".png");
+    else
+        return QString();
 }
