@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2010-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2010-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@
 
 // Forward Declarations
 class KIcon;
-class QWebPage;
+class QWebFrame;
 class KJob;
 
 
@@ -47,22 +47,22 @@ public:
     IconManager(QObject *parent = 0);
 
     KIcon iconForUrl(const KUrl &url);
+    QString iconPathForUrl(const KUrl &url);
 
-    void provideIcon(QWebPage *page, const KUrl &url, bool notify = true);
+    void provideIcon(QWebFrame *mFrame, const KUrl &url, bool notify = true);
 
     void downloadIconFromUrl(const KUrl &url);
 
     void clearIconCache();
 
-private Q_SLOTS:
-    void doLastStuffs(KJob *);
-    void notifyLastStuffs(KJob *);
+    void saveDesktopIconForUrl(const KUrl &u);
 
 Q_SIGNALS:
     void iconChanged();
 
 private:
     bool existsIconForUrl(const KUrl &url);
+    QString favIconForUrl(const KUrl &url);
 
     QString _faviconsDir;
 };
