@@ -3,7 +3,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2008-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2008-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2009 by Paweł Prażak <pawelprazak at gmail dot com>
 * Copyright (C) 2009-2011 by Lionel Chauvin <megabigbug@yahoo.fr>
 * Copyright (C) 2010 by Matthieu Gicquel <matgic78 at gmail dot com>
@@ -45,6 +45,7 @@ class FindBar;
 class HistoryPanel;
 class MainView;
 class NetworkAnalyzerPanel;
+class RekonqMenu;
 class WebInspectorPanel;
 class WebTab;
 class ZoomBar;
@@ -89,7 +90,8 @@ private:
     void setupPanels();
 
 public Q_SLOTS:
-    void homePage(Qt::MouseButtons = Qt::LeftButton, Qt::KeyboardModifiers = Qt::NoModifier);
+    void openDownloadsPage();
+    void homePage();
 
     /**
      * Notifies a message in a popup
@@ -103,7 +105,8 @@ public Q_SLOTS:
 
     void printRequested(QWebFrame *frame = 0);
 
-    void updateActions();
+    void updateHistoryActions();
+    void updateTabActions();
 
     virtual void configureToolbars();
 
@@ -141,10 +144,10 @@ protected:
 
     bool event(QEvent *event);
 
+    void readProperties(const KConfigGroup & config);
     void finalizeGUI(KXMLGUIClient *client);
 
 private Q_SLOTS:
-    void browserLoading(bool);
     void updateWindowTitle(const QString &title = QString());
 
     // history related
@@ -176,17 +179,19 @@ private Q_SLOTS:
     void openActionUrl(QAction *action);
     void openActionTab(QAction *action);
 
-    // user agent
-    void setUserAgent();
     void populateUserAgentMenu();
-    void showUserAgentSettings();
 
     void enableNetworkAnalysis(bool);
     void setEditable(bool);
 
-    void initBookmarkBar();
     void toggleBookmarkBarVisible(bool);
 
+    /**
+     * This is for the things to do ABSOLUTELY AFTER ctor launch:
+     * the less, the better.
+     */
+    void postLaunch();
+
 private:
     MainView *m_view;
     FindBar *m_findBar;
@@ -197,15 +202,13 @@ private:
     WebInspectorPanel *m_webInspectorPanel;
     NetworkAnalyzerPanel *m_analyzerPanel;
 
-    KAction *m_stopReloadAction;
+    KAction *m_loadStopReloadAction;
 
     KMenu *m_historyBackMenu;
     KMenu *m_historyForwardMenu;
 
     KMenu *m_tabListMenu;
 
-    KMenu *m_userAgentMenu;
-
     BookmarkToolBar *m_bookmarksBar;
 
     QString m_lastSearch;
@@ -213,7 +216,7 @@ private:
     QLabel *m_popup;
     QTimer *m_hidePopupTimer;
 
-    KMenu *m_rekonqMenu;
+    RekonqMenu *m_rekonqMenu;
 };
 
 #endif // MAINWINDOW_H
