@@ -35,11 +35,11 @@ class WebPageTest : public QObject
 {
     Q_OBJECT
 
-public slots:
+public Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
 
-private slots:
+private Q_SLOTS:
     void manageNetworkErrors();
     void downloadRequest();
     void downloadAllContentsWithKGet();
