@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -53,12 +53,12 @@ public:
 
     void suggestUrls(const QString &text);
 
-private slots:
+private Q_SLOTS:
     void itemChosen(ListItem *item, Qt::MouseButton = Qt::LeftButton, Qt::KeyboardModifiers = Qt::NoModifier);
     void updateSearchList(const UrlSearchList &list, const QString& text);
     void updateList();
 
-signals:
+Q_SIGNALS:
     void chosenUrl(const KUrl &, Rekonq::OpenType);
     void nextItemSubChoice();
 
