@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -160,7 +160,7 @@ void ListItem::nextItemSubChoice()
 TypeIconLabel::TypeIconLabel(int type, QWidget *parent)
     : QLabel(parent)
 {
-    setMinimumWidth(40);
+    setMinimumWidth(16);
     QHBoxLayout *hLayout = new QHBoxLayout;
     hLayout->setMargin(0);
     hLayout->setAlignment(Qt::AlignRight);
@@ -217,7 +217,7 @@ static QString highlightWordsInText(const QString &text, const QStringList &word
 {
     QString ret = text;
     QBitArray boldSections(ret.size());
-    foreach(const QString & wordToPointOut, words)
+    Q_FOREACH(const QString & wordToPointOut, words)
     {
         int index = ret.indexOf(wordToPointOut, 0, Qt::CaseInsensitive);
         while (index > -1)
@@ -309,7 +309,7 @@ DescriptionLabel::DescriptionLabel(const QString &text, QWidget *parent)
     if (wasItalic)
         t = QL1S("<i>") + t + QL1S("</i>");
 
-    setWordWrap(false); //TODO: why setWordWrap(true) make items have a strange behavior ?
+    setWordWrap(false); //NOTE: why setWordWrap(true) make items have a strange behavior ?
     setText(t);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Maximum);
 }
@@ -324,13 +324,10 @@ PreviewListItem::PreviewListItem(const UrlSearchItem &item, const QString &text,
     QHBoxLayout *hLayout = new QHBoxLayout;
     hLayout->setSpacing(4);
 
-    QLabel *previewLabelIcon = new QLabel(this);
-    previewLabelIcon->setFixedSize(45, 33);
-    new PreviewLabel(item.url, 38, 29, previewLabelIcon);
-    IconLabel* icon = new IconLabel(item.url, previewLabelIcon);
-    icon->move(27, 16);
-    hLayout->addWidget(previewLabelIcon);
+    // icon
+    hLayout->addWidget(new TypeIconLabel(item.type, this));
 
+    // url + text
     QVBoxLayout *vLayout = new QVBoxLayout;
     vLayout->setMargin(0);
 
@@ -344,10 +341,15 @@ PreviewListItem::PreviewListItem(const UrlSearchItem &item, const QString &text,
 
     vLayout->addWidget(new TextLabel(title, text, this));
     vLayout->addWidget(new TextLabel("<i>" + item.url + "</i>", text, this));
-
     hLayout->addLayout(vLayout);
 
-    hLayout->addWidget(new TypeIconLabel(item.type, this));
+    // preview label icon
+    QLabel *previewLabelIcon = new QLabel(this);
+    previewLabelIcon->setFixedSize(45, 33);
+    new PreviewLabel(item.url, 38, 29, previewLabelIcon);
+    IconLabel* icon = new IconLabel(item.url, previewLabelIcon);
+    icon->move(27, 16);
+    hLayout->addWidget(previewLabelIcon);
 
     setLayout(hLayout);
 }
@@ -389,10 +391,10 @@ ImageLabel::ImageLabel(const QString &url, int width, int height, QWidget *paren
     else
     {
         KIO::TransferJob *job = KIO::get(KUrl(url), KIO::NoReload, KIO::HideProgressInfo);
-        connect(job,  SIGNAL(data(KIO::Job *, const QByteArray &)),
-                this, SLOT(slotData(KIO::Job*, const QByteArray&)));
-        connect(job,  SIGNAL(result(KJob *)),
-                this, SLOT(slotResult(KJob *)));
+        connect(job,  SIGNAL(data(KIO::Job*,QByteArray)),
+                this, SLOT(slotData(KIO::Job*,QByteArray)));
+        connect(job,  SIGNAL(result(KJob*)),
+                this, SLOT(slotResult(KJob*)));
     }
 }
 
@@ -449,8 +451,11 @@ QString SearchListItem::text()
 
 void SearchListItem::changeSearchEngine(KService::Ptr engine)
 {
-    UrlResolver::setSearchEngine(engine);
-    emit updateList();
+    // NOTE: This to let rekonq loading text typed in the requested engine on click.
+    // There probably is a better way to do it. I just cannot see it now...
+    UrlSearchItem item = UrlSearchItem(UrlSearchItem::Search, SearchEngine::buildQuery(engine, m_text), m_text);
+    SearchListItem sItem(item, m_text, this);
+    emit itemClicked(&sItem, Qt::LeftButton, Qt::NoModifier);
 }
 
 
@@ -475,7 +480,7 @@ EngineBar::EngineBar(KService::Ptr selectedEngine, QWidget *parent)
     if (SearchEngine::defaultEngine().isNull())
         return;
     m_engineGroup->addAction(newEngineAction(SearchEngine::defaultEngine(), selectedEngine));
-    foreach(const KService::Ptr & engine, SearchEngine::favorites())
+    Q_FOREACH(const KService::Ptr & engine, SearchEngine::favorites())
     {
         if (engine->desktopEntryName() != SearchEngine::defaultEngine()->desktopEntryName())
         {
